States
======

The built-in :class:`~piquasso.api.state.State` classes in Piquasso.

.. toctree::
   :maxdepth: 3
   :hidden:

   gaussian
   fock
   sampling


.. grid:: 3

   .. grid-item-card::  GaussianState
      :link: gaussian
      :link-type: doc
      :class-title: cardclass

      Class to represent a Gaussian state.

   .. grid-item-card::  FockState and PureFockState
      :link: fock
      :link-type: doc

      Classes to represent a mixed or pure photonic states in the Fock basis.

   .. grid-item-card::  SamplingState
      :link: sampling
      :link-type: doc

      Class to represent the state in a Boson Sampling expermiment before measurement.

